pub struct DebuggingAssistantParams {
pub issue_type: Option<String>,
pub include_solutions: Option<bool>,
}Fields
issue_type: Option<String>include_solutions: Option<bool>Trait Implementations
Sourceimpl Clone for DebuggingAssistantParams
impl Clone for DebuggingAssistantParams
Sourcefn clone(&self) -> DebuggingAssistantParams
fn clone(&self) -> DebuggingAssistantParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DebuggingAssistantParams
impl Debug for DebuggingAssistantParams
Sourceimpl<'de> Deserialize<'de> for DebuggingAssistantParams
impl<'de> Deserialize<'de> for DebuggingAssistantParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DebuggingAssistantParams
impl JsonSchema for DebuggingAssistantParams
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DebuggingAssistantParams
impl RefUnwindSafe for DebuggingAssistantParams
impl Send for DebuggingAssistantParams
impl Sync for DebuggingAssistantParams
impl Unpin for DebuggingAssistantParams
impl UnsafeUnpin for DebuggingAssistantParams
impl UnwindSafe for DebuggingAssistantParams