pub struct TestingIntegrationParams {
pub test_type: Option<String>,
pub include_examples: Option<bool>,
}Fields
test_type: Option<String>include_examples: Option<bool>Trait Implementations
Sourceimpl Clone for TestingIntegrationParams
impl Clone for TestingIntegrationParams
Sourcefn clone(&self) -> TestingIntegrationParams
fn clone(&self) -> TestingIntegrationParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestingIntegrationParams
impl Debug for TestingIntegrationParams
Sourceimpl<'de> Deserialize<'de> for TestingIntegrationParams
impl<'de> Deserialize<'de> for TestingIntegrationParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TestingIntegrationParams
impl JsonSchema for TestingIntegrationParams
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TestingIntegrationParams
impl RefUnwindSafe for TestingIntegrationParams
impl Send for TestingIntegrationParams
impl Sync for TestingIntegrationParams
impl Unpin for TestingIntegrationParams
impl UnsafeUnpin for TestingIntegrationParams
impl UnwindSafe for TestingIntegrationParams